@@ -4,6 +4,6 @@
 - query.py
 - srun.sh
 '''
-from .set_gpu import set_gpu
+from .set_gpu import set_gpu, get_public_net
 from .kill import get_nvidia_processes, get_ps_processes, get_user_processes, kill_processes
-from .notice import send_wechat, get_time_diff
\ No newline at end of file
+from .notice import send_wechat, get_time_diff, explain_exit_code
\ No newline at end of file
